@@ -5,7 +5,7 @@
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#if !defined(__FreeBSD__) && !defined(__DARWIN__)
+#if !defined(__FreeBSD__) && !defined(__DARWIN__) && !defined(_WIN32)
 #define alloca 
 #endif //!defined(__FreeBSD__) && !defined(__DARWIN__)
 
@@ -56,7 +56,9 @@
 #define	MAX_TM_ROW3	295
 
 #include <common/Defines.h>
-#include <3dsparse/ASEFile.h>
+#include <3dsparse/ASEModelFactory.h>
+
+static Vector tmRow[3];
 
 Face aseFace;
 int aseFaceNo;
@@ -790,22 +792,43 @@ yyreduce:
   switch (yyn) {
 
 case 9:
-{ ASEFile::getCurrent()->getCurrentModel()->setColor(aseVector); ;
-    break;}
+{ 
+	Vector4 ambientColor(0.6f, 0.6f, 0.6f, 1.0f);
+	Vector4 diffuseColor(0.8f, 0.8f, 0.8f, 1.0f);
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getAmbientColor() = ambientColor;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getDiffuseColor() = diffuseColor;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getEmissiveColor() = Vector::getNullVector();
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getSpecularColor() = Vector::getNullVector();
+
+	Vector ambientNoTexColor = aseVector * 0.6f;
+	Vector diffuseNoTexColor = aseVector * 0.8f;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getAmbientNoTexColor() = ambientNoTexColor;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getDiffuseNoTexColor() = diffuseNoTexColor;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getEmissiveNoTexColor() = Vector::getNullVector();
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getSpecularNoTexColor() = Vector::getNullVector();
+
+	ASEModelFactory::getCurrent()->getCurrentMesh()->getShininessColor() = 0.0f;
+
+	break;
+}
 case 10:
-{ ASEFile::getCurrent()->addModel(aseString); ;
+{ ASEModelFactory::getCurrent()->addMesh(aseString); ;
     break;}
 case 12:
-{ ASEFile::getCurrent()->getCurrentModel()->setTmRow(aseVector, 0); ;
+{ tmRow[0] = aseVector.Normalize(); 
     break;}
 case 13:
-{ ASEFile::getCurrent()->getCurrentModel()->setTmRow(aseVector, 1); ;
+{ tmRow[1] = aseVector.Normalize(); 
     break;}
 case 14:
-{ ASEFile::getCurrent()->getCurrentModel()->setTmRow(aseVector, 2); ;
+{ tmRow[2] = aseVector.Normalize(); 
     break;}
 case 18:
-{ ASEFile::getCurrent()->getCurrentModel()->insertVertex(aseVector); ;
+{ 
+	Vertex vertex;
+	vertex.position = aseVector;
+	vertex.boneIndex = -1;
+	ASEModelFactory::getCurrent()->getCurrentMesh()->insertVertex(vertex); ;
     break;}
 case 22:
 { aseFace.v[0] = aseDigit; ;
@@ -816,20 +839,38 @@ case 23:
 case 24:
 { 
 		aseFace.v[2] = aseDigit;
-		ASEFile::getCurrent()->getCurrentModel()->insertFace(aseFace);	
+		ASEModelFactory::getCurrent()->getCurrentMesh()->insertFace(aseFace);	
 	;
     break;}
 case 28:
 { aseFaceNo = aseDigit; ;
     break;}
 case 29:
-{ ASEFile::getCurrent()->getCurrentModel()->setFaceNormal(aseVector, aseFaceNo, 0); ;
+{ 
+	Vector n(
+		aseVector[0] * tmRow[0][0] + aseVector[1] * tmRow[1][0] + aseVector[2] * tmRow[2][0],
+		aseVector[0] * tmRow[0][1] + aseVector[1] * tmRow[1][1] + aseVector[2] * tmRow[2][1],
+		aseVector[0] * tmRow[0][2] + aseVector[1] * tmRow[1][2] + aseVector[2] * tmRow[2][2]);
+
+	ASEModelFactory::getCurrent()->getCurrentMesh()->setFaceNormal(n, aseFaceNo, 0);
     break;}
 case 30:
-{ ASEFile::getCurrent()->getCurrentModel()->setFaceNormal(aseVector, aseFaceNo, 1); ;
+{ 
+	Vector n(
+		aseVector[0] * tmRow[0][0] + aseVector[1] * tmRow[1][0] + aseVector[2] * tmRow[2][0],
+		aseVector[0] * tmRow[0][1] + aseVector[1] * tmRow[1][1] + aseVector[2] * tmRow[2][1],
+		aseVector[0] * tmRow[0][2] + aseVector[1] * tmRow[1][2] + aseVector[2] * tmRow[2][2]);
+
+	ASEModelFactory::getCurrent()->getCurrentMesh()->setFaceNormal(n, aseFaceNo, 1);
     break;}
 case 31:
-{ ASEFile::getCurrent()->getCurrentModel()->setFaceNormal(aseVector, aseFaceNo, 2); ;
+{ 
+	Vector n(
+		aseVector[0] * tmRow[0][0] + aseVector[1] * tmRow[1][0] + aseVector[2] * tmRow[2][0],
+		aseVector[0] * tmRow[0][1] + aseVector[1] * tmRow[1][1] + aseVector[2] * tmRow[2][1],
+		aseVector[0] * tmRow[0][2] + aseVector[1] * tmRow[1][2] + aseVector[2] * tmRow[2][2]);
+
+	ASEModelFactory::getCurrent()->getCurrentMesh()->setFaceNormal(n, aseFaceNo, 2);
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
@@ -1032,7 +1073,7 @@ yyerrhandle:
 int aseerror(const char *errmsg)
 {
 	char buffer[1024];
-	sprintf(buffer, "%i:%s\n", aselineno, errmsg);
+	snprintf(buffer, 1024, "%i:%s\n", aselineno, errmsg);
 	dialogMessage("Lexer", buffer);
     return 0;
 }
@@ -1040,7 +1081,7 @@ int aseerror(const char *errmsg)
 int asewarning(const char *warningmsg)
 {
 	char buffer[1024];
-	sprintf(buffer, "%i:%s\n", aselineno, warningmsg);
+	snprintf(buffer, 1024, "%i:%s\n", aselineno, warningmsg);
 	dialogMessage("Lexer", buffer);
     return 0;
 }
@@ -1048,7 +1089,7 @@ int asewarning(const char *warningmsg)
 int asedebug(const char *debugmsg)
 {
 	char buffer[1024];
-	sprintf(buffer, "%i:%s\n", aselineno, debugmsg);
+	snprintf(buffer, 1024, "%i:%s\n", aselineno, debugmsg);
 	dialogMessage("Lexer", buffer);
     return 0;
 }
