@@ -30,14 +30,13 @@ class ClientDefenseHandler :
 public:
 	static ClientDefenseHandler *instance();
 
-	unsigned int getLocalTankMessageCount() { return messageCount_; }
-	virtual bool processMessage(unsigned int id,
+	virtual bool processMessage(
+		NetMessage &message,
 		const char *messageType,
 		NetBufferReader &reader);
 
 protected:
 	static ClientDefenseHandler *instance_;
-	unsigned int messageCount_;
 
 private:
 	ClientDefenseHandler();
