@@ -22,7 +22,6 @@
 #define __INCLUDE_ComsGameStateMessageh_INCLUDE__
 
 #include <coms/ComsMessage.h>
-#include <coms/ComsPlayerStateMessage.h>
 
 class ComsGameStateMessage : public ComsMessage
 {
@@ -35,7 +34,6 @@ public:
     virtual bool readMessage(NetBufferReader &reader);
 
 protected:
-	ComsPlayerStateMessage stateMessage_;
 };
 
 
