@@ -29,12 +29,12 @@ class ServerAdminHandler :
 public:
 	static ServerAdminHandler *instance();
 
-	virtual bool processMessage(unsigned int id,
+	// Inherited from ComsMessageHandlerI
+	virtual bool processMessage(
+		NetMessage &message,
 		const char *messageType,
 		NetBufferReader &reader);
-
 protected:
-	bool login(const char *name, const char *password);
 
 private:
 	ServerAdminHandler();
